=== modified file 'drizzled/display.cc'
--- drizzled/display.cc	2010-12-24 21:27:54 +0000
+++ drizzled/display.cc	2010-12-27 01:12:01 +0000
@@ -76,6 +76,7 @@
 static const std::string CACHE_ITEM("CACHE_ITEM");
 static const std::string TYPE_HOLDER("TYPE_HOLDER");
 static const std::string PARAM_ITEM("PARAM_ITEM");
+static const std::string BOOLEAN_ITEM("BOOLEAN_ITEM");
 static const std::string DECIMAL_ITEM("DECIMAL_ITEM");
 
 static const std::string ITEM_CAST_BINARY("ITEM_CAST_BINARY");
@@ -186,6 +187,8 @@
     return TYPE_HOLDER;
   case drizzled::Item::PARAM_ITEM :
     return PARAM_ITEM;
+  case drizzled::Item::BOOLEAN_ITEM :
+    return BOOLEAN_ITEM;
   case drizzled::Item::DECIMAL_ITEM :
     return DECIMAL_ITEM;
   }

=== modified file 'drizzled/item.h'
--- drizzled/item.h	2010-12-24 21:27:54 +0000
+++ drizzled/item.h	2010-12-27 01:12:01 +0000
@@ -111,6 +111,7 @@
     ROW_ITEM, CACHE_ITEM,
     TYPE_HOLDER,
     PARAM_ITEM,
+    BOOLEAN_ITEM,
     DECIMAL_ITEM
   };
   enum traverse_order
@@ -165,6 +166,7 @@
    * Alloc & destruct is done as start of select using memory::sql_alloc
    */
   Item();
+
   /**
    * Constructor used by Item_field, Item_ref & aggregate (sum) functions.
    *
@@ -179,7 +181,7 @@
   virtual ~Item()
   {
 #ifdef EXTRA_DEBUG
-    name=0;
+    name= NULL;
 #endif
   }
 

=== modified file 'drizzled/item/basic_constant.h'
--- drizzled/item/basic_constant.h	2010-12-18 04:43:40 +0000
+++ drizzled/item/basic_constant.h	2010-12-27 01:12:01 +0000
@@ -28,7 +28,10 @@
 class Item_basic_constant :public Item
 {
 public:
-  Item_basic_constant() : Item() {}
+  Item_basic_constant() :
+    Item()
+  {
+  }
 
   /* to prevent drop fixed flag (no need parent cleanup call) */
   void cleanup()

=== added file 'drizzled/item/boolean.h'
--- drizzled/item/boolean.h	1970-01-01 00:00:00 +0000
+++ drizzled/item/boolean.h	2010-12-27 01:12:01 +0000
@@ -0,0 +1,108 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_ITEM_BOOLEAN_H
+#define DRIZZLED_ITEM_BOOLEAN_H
+
+#include "drizzled/item/basic_constant.h"
+
+namespace drizzled
+{
+
+namespace item
+{
+
+class Boolean: public Item_basic_constant
+{
+  bool value;
+
+public:
+  Boolean(const char *str_arg, bool arg) :
+    Item_basic_constant(),
+    value(arg)
+  {
+    max_length= value ? 4 : 5;
+    fixed= true;
+    name= (const_cast<char *>(str_arg));
+  }
+
+  Boolean(bool arg) :
+    value(arg)
+  {
+    max_length= value ? 4 : 5;
+    fixed= true;
+
+    if (value)
+    {
+      name= const_cast<char *>("TRUE");
+    }
+    else
+    {
+      name= const_cast<char *>("FALSE");
+    }
+  }
+
+  enum Type type() const { return BOOLEAN_ITEM; }
+
+  virtual bool val_bool()
+  {
+    return value;
+  }
+
+  double val_real()
+  {
+    return value ? 1 : 0;
+  }
+
+  int64_t val_int() 
+  {
+    return value ? 1 : 0;
+  }
+
+  drizzled::String* val_str(drizzled::String *value_buffer)
+  {
+    value_buffer->realloc(5);
+
+    if (value)
+    {
+      value_buffer->append("TRUE");
+    }
+    else
+    {
+      value_buffer->append("FALSE");
+    }
+
+    return value_buffer;
+  }
+
+  drizzled::my_decimal* val_decimal(drizzled::my_decimal *dec)
+  {
+    (void)dec;
+    return 0;
+  }
+
+};
+
+} /* namespace item */
+} /* namespace drizzled */
+
+#include "drizzled/item/true.h"
+#include "drizzled/item/false.h"
+
+#endif /* DRIZZLED_ITEM_BOOLEAN_H */

=== added file 'drizzled/item/false.h'
--- drizzled/item/false.h	1970-01-01 00:00:00 +0000
+++ drizzled/item/false.h	2010-12-27 01:12:01 +0000
@@ -0,0 +1,50 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_ITEM_FALSE_H
+#define DRIZZLED_ITEM_FALSE_H
+
+#include "drizzled/item/boolean.h"
+
+namespace drizzled
+{
+
+namespace item
+{
+
+class Boolean;
+
+class False: public Boolean
+{
+public:
+  False() :
+    Boolean(false)
+  {
+  }
+
+  False(const char *str_arg) :
+    Boolean(str_arg, false)
+  {
+  }
+};
+
+} /* namespace item */
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_ITEM_FALSE_H */

=== added file 'drizzled/item/true.h'
--- drizzled/item/true.h	1970-01-01 00:00:00 +0000
+++ drizzled/item/true.h	2010-12-27 01:12:01 +0000
@@ -0,0 +1,49 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_ITEM_TRUE_H
+#define DRIZZLED_ITEM_TRUE_H
+
+namespace drizzled
+{
+
+namespace item
+{
+
+class Boolean;
+
+class True: public Boolean
+{
+public:
+  True() :
+    Boolean(true)
+  {
+  }
+
+  True(const char *str_arg) :
+    Boolean(str_arg, true)
+  {
+  }
+
+};
+
+} /* namespace item */
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_ITEM_TRUE_H */

=== modified file 'drizzled/parser.h'
--- drizzled/parser.h	2010-10-23 21:00:18 +0000
+++ drizzled/parser.h	2010-12-27 01:12:01 +0000
@@ -105,4 +105,6 @@
 #include "drizzled/charset.h"
 #include "drizzled/internal/m_string.h"
 
+#include "drizzled/item/boolean.h"
+
 #endif /* DRIZZLED_PARSER_H */

=== modified file 'drizzled/sql_string.h'
--- drizzled/sql_string.h	2010-12-24 05:50:22 +0000
+++ drizzled/sql_string.h	2010-12-27 01:12:01 +0000
@@ -217,13 +217,13 @@
       char *new_ptr;
       if (!(new_ptr= reinterpret_cast<char*>(::realloc(Ptr,arg_length))))
       {
-	Alloced_length = 0;
-	real_alloc(arg_length);
+        Alloced_length = 0;
+        real_alloc(arg_length);
       }
       else
       {
-	Ptr=new_ptr;
-	Alloced_length=arg_length;
+        Ptr=new_ptr;
+        Alloced_length=arg_length;
       }
     }
   }
@@ -272,7 +272,7 @@
     else
     {
       if (realloc(str_length+1))
-	return 1;
+        return 1;
       Ptr[str_length++]=chr;
     }
     return 0;

=== modified file 'drizzled/sql_yacc.yy'
--- drizzled/sql_yacc.yy	2010-12-24 21:27:54 +0000
+++ drizzled/sql_yacc.yy	2010-12-27 01:12:01 +0000
@@ -5934,8 +5934,8 @@
             $$ = new Item_null();
             YYSession->m_lip->next_state=MY_LEX_OPERATOR_OR_IDENT;
           }
-        | FALSE_SYM { $$= new Item_int((char*) "FALSE",0,1); }
-        | TRUE_SYM { $$= new Item_int((char*) "TRUE",1,1); }
+        | FALSE_SYM { $$= new item::False(); }
+        | TRUE_SYM { $$= new item::True(); }
         | HEX_NUM { $$ = new Item_hex_string($1.str, $1.length);}
         | BIN_NUM { $$= new Item_bin_string($1.str, $1.length); }
         | DATE_SYM text_literal { $$ = $2; }

